skiptools.Skip
==============

.. abjad-lineage:: abjad.tools.skiptools.Skip.Skip.Skip

.. autoclass:: abjad.tools.skiptools.Skip.Skip.Skip
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.descendants
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.leaf_index
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.lineage
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.override
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.parent
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.parentage
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.prolation
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.set
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.spanners
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.start_offset
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.storage_format
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.timespan
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.written_duration
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.skiptools.Skip.Skip.Skip.written_pitch_indication_is_nonsemantic
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__and__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__eq__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__ge__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__gt__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__le__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__lt__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__mul__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__ne__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__or__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__repr__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__rmul__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__str__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__sub__
   :noindex:

.. automethod:: abjad.tools.skiptools.Skip.Skip.Skip.__xor__
   :noindex:
